@@ -61,7 +61,7 @@ def compose_integration_logs(job_uuid, segments, file_pattern, time, id_types, o
 
 
 def get_delivery_error_type(exception):
-    from exceptions import AuthenticationError, ConfigurationError, NotFoundError
+    from .exceptions import AuthenticationError, ConfigurationError, NotFoundError
     if isinstance(exception, AuthenticationError):
         error_type = 'Authentication Error'
     elif isinstance(exception, ConfigurationError):
